@@ -1,4 +1,4 @@
-static const char rcsid[] = "$Id: approve.c,v 1.153 2007/12/20 16:26:38 will Exp $";
+static const char rcsid[] = "$Id: approve.c,v 1.154 2020/08/03 17:13:04 will Exp $";
 
 /* The code should compile with either ANSI C or K&R compilers. */
 
@@ -77,7 +77,7 @@ int verbosity;		/* HELP_BASIC, HELP_FULL, or HELP_FACTS */
 	error_nl = currfile->nl;
 
 	if (!indentok) {
-	    Error(0, 0, "%t\n\tformat error in super.tab file:\n\
+	    Error(0, 0, "$$\n\tformat error in super.tab file:\n\
 \tContinued line not indented.\n");
 	    if (check_syntax) {
 		continue;
@@ -93,7 +93,7 @@ int verbosity;		/* HELP_BASIC, HELP_FULL, or HELP_FACTS */
 	    continue;
 
 	if (bbuf != buf) {
-	    Error(0, 0, "%t\n\tformat error in super(1) file: \n\
+	    Error(0, 0, "$$\n\tformat error in super(1) file: \n\
 \tNon-comments must begin in column 1.\n");
 	    if (check_syntax) {
 		continue;
@@ -224,7 +224,7 @@ char *usrcmd;		/* Command user wants to execute -- can be
 	return 0;		/* Discard empty lines and pure-comment lines */
     
     if (bbuf != buf) {
-	return Error(0, 0, "%t\n\tformat error in super(1) file: \n\
+	return Error(0, 0, "$$\n\tformat error in super(1) file: \n\
 \tCommandPatterns must begin in column 1.\n");
     }
 
@@ -236,7 +236,7 @@ char *usrcmd;		/* Command user wants to execute -- can be
 	int nalloc = 10;
 	if ( !(localinfo.progs.cmd_file = (ProgList *)
 				malloc(nalloc * sizeof(ProgList))) )
-	    return Error(1, 0, "%tFailed to malloc space for Cmd+File list\n");
+	    return Error(1, 0, "$$Failed to malloc space for Cmd+File list\n");
 	localinfo.progs.nalloc = 10;
     }
     localinfo.progs.n = 0;	/* Initialize to 0 cmd/file pairs */
@@ -247,7 +247,7 @@ char *usrcmd;		/* Command user wants to execute -- can be
      */
     word1 = strqtokS(buf, SEP, NULL, NULL, 1);
     if (!word1)
-	return Error(0, 0, "%t\n\tformat error in super.tab file: \
+	return Error(0, 0, "$$\n\tformat error in super.tab file: \
 CmdPattern or FullPathName missing.\n");
 
     do {
@@ -376,7 +376,7 @@ char **cond_or_opt_wd;
 		fprintf(stderr, "\tCommand::file = `%s'\n", pair);
 
 	    if (coloncolon == pair)
-		return Error(0, 0, "%t\n\tFormat error in super.tab file:\n\
+		return Error(0, 0, "$$\n\tFormat error in super.tab file:\n\
 \tCmd::File used, but the Cmd part is missing.\n");
 	    *coloncolon = '\0';
 	    localinfo.progs.n++;	/* Have a new cmd/file pair */
@@ -387,7 +387,7 @@ char **cond_or_opt_wd;
 				localinfo.progs.nalloc * sizeof(ProgList));
 		if (!localinfo.progs.cmd_file)
 		    return Error(1, 0,
-			"%tFailed to malloc space for Cmd+File list\n");
+			"$$Failed to malloc space for Cmd+File list\n");
 	    }
 
 	    localinfo.progs.cmd_file[localinfo.progs.n - 1].Cmd = pair;
@@ -401,13 +401,13 @@ char **cond_or_opt_wd;
 		localinfo.progs.evermatched = 1;
 		if (localinfo.progs.cmd_file[localinfo.progs.match].File[0]
 				== '\0')
-		    return Error(0, 0, "%t\n\tFormat error in super.tab file:\n\
+		    return Error(0, 0, "$$\n\tFormat error in super.tab file:\n\
 \tCmd::File used, but the File part is missing.\n");
 
 		if (globalinfo.relative_path == 0 &&
 		    localinfo.progs.cmd_file[localinfo.progs.match].File[0]
 				!= '/')
-		    return Error(0, 0, "%t\n\tFormat error in super.tab file:\n\
+		    return Error(0, 0, "$$\n\tFormat error in super.tab file:\n\
 \tfilename `%s' is not an absolute path.\n\
 \tUse global option relative_path=y if you really want such foolishness!\n",
 		    localinfo.progs.cmd_file[localinfo.progs.match].File);
@@ -424,7 +424,7 @@ char **cond_or_opt_wd;
     } else if (s && *s == ':') {
 	/* Embedded `:' in command name! */
 
-	return Error(0, 0, "%t\n\tFormat error in super.tab file: \
+	return Error(0, 0, "$$\n\tFormat error in super.tab file: \
 The CmdPattern (%s) may not contain an embedded colon\n", word1);
 
     } else {
@@ -435,12 +435,12 @@ The CmdPattern (%s) may not contain an embedded colon\n", word1);
 	localinfo.progs.cmd_file[0].File = strqtokS(NULL, SEP, NULL, NULL, 1);
 	if (localinfo.progs.cmd_file[0].File == NULL ||
 				localinfo.progs.cmd_file[0].File[0] == '\0')
-	    return Error(0, 0, "%t\n\tformat error in super.tab file: \
+	    return Error(0, 0, "$$\n\tformat error in super.tab file: \
 CmdPattern or FullPathName missing.\n");
 
 	    if (globalinfo.relative_path == 0 &&
 			localinfo.progs.cmd_file[0].File[0] != '/')
-		return Error(0, 0, "%t\n\tFormat error in super.tab file: \
+		return Error(0, 0, "$$\n\tFormat error in super.tab file: \
 filename `%s' is not an absolute path.\n\
 \tUse global option relative_path=y if you really want such foolishness!\n",
 		localinfo.progs.cmd_file[0].File);
@@ -500,11 +500,11 @@ backslashes in the cmd!\n", usrcmd);
 
 	if ((strlen(path) + strlen(usrcmd)) > l_FullPath)
 	    return Error(0, 0,
-	    "%t\n\tRidiculously long path would be formed from Cmd \
+	    "$$\n\tRidiculously long path would be formed from Cmd \
 and FullPathName:\n<%s> + <%s>", path, usrcmd);
 	if ((q=strchr(p+1, '*')) && q < (path + lpath))
 	    return Error(0, 0,
-		"%t\n\tFullPathName can only have 1 asterisk, \
+		"$$\n\tFullPathName can only have 1 asterisk, \
 but the superfile entry\nreads `%s'\n", path);
 	if (n > 0)
 	    strncpy(FullPath, path, n);
@@ -541,7 +541,7 @@ char *cond_or_opt_wd;	/* First word to process; rest we get with strqtokS */
 
 	    p = cond_or_opt_wd;
 	    if (*p == CONDITION_SEP || *p == OPTION_SEP)
-		return Error(0, 0, "%t\n\tBad syntax: <%s>\n", cond_or_opt_wd);
+		return Error(0, 0, "$$\n\tBad syntax: <%s>\n", cond_or_opt_wd);
 
 	    for (p++; *p && ((*p != CONDITION_SEP && *p != OPTION_SEP) ||
 						    (*(p-1) == '\\')); p++)
@@ -574,10 +574,10 @@ char *cond_or_opt_wd;	/* First word to process; rest we get with strqtokS */
 
 		/* Do brace globbing */
 		if (balancedbraces(s) != 0) {
-		    return Error(0, 0, "%tUnbalanced braces in `%s'.\n", s);
+		    return Error(0, 0, "$$Unbalanced braces in `%s'.\n", s);
 		}
 		if ((i=globbraces(s, 1, &glob)) != 0) {
-		    return Error(0, 0, "%tMissing `%c'.\n", i);
+		    return Error(0, 0, "$$Missing `%c'.\n", i);
 		}
 
 		if (InsertUserList(s, glob,
@@ -618,7 +618,7 @@ char *cond_or_opt_wd;	/* First word to process; rest we get with strqtokS */
 	}
     } else {
 	return Error(0, 0,
-	"%t\n\tNo user patterns given on control line or in :global line.\n");
+	"$$\n\tNo user patterns given on control line or in :global line.\n");
     }
     if (!matches.user)
 	condition_match = 0;
@@ -827,7 +827,7 @@ int verbosity;
 			localinfo.progs.cmd_file[i].Cmd,
 			localinfo.progs.cmd_file[i].File);
     } else {
-	(void) Error(0, 0, "%s: printhelp(): Unknown verbosity level %d\n",
+	(void) Error(0, 0, "$$printhelp(): Unknown verbosity level %d\n",
 			verbosity);
 	return;
     }
