@@ -1,4 +1,4 @@
-static const char rcsid[] = "$Id: checks.c,v 1.190 2007/03/07 15:04:41 will Exp $";
+static const char rcsid[] = "$Id: checks.c,v 1.191 2020/08/03 17:13:04 will Exp $";
 /* The code should compile with either ANSI C or K&R compilers. */
 
 /*
@@ -26,7 +26,7 @@ static char *NO  = "N";
  */
 
 static int created_user_table = 0;
-static netgrp_u_compare(pattern, user)
+static int netgrp_u_compare(pattern, user)
   char *pattern;
   char *user;
 {
@@ -36,7 +36,7 @@ static netgrp_u_compare(pattern, user)
     if (!created_user_table) {
         if (!s_hcreate(HS_USER, 1000)) {
 	    return Error(0, 0,
-		"%tCouldn't allocate hash table for user ng processing\n");
+		"$$Couldn't allocate hash table for user ng processing\n");
 	}
         created_user_table = 1;
     }
@@ -46,7 +46,7 @@ static netgrp_u_compare(pattern, user)
      */
     if (snprintf(keybuf, MAX_KEYLEN, "%s\n%s", pattern, user) >= MAX_KEYLEN) {
          return Error(0, 0,
-             "%tpattern and user too large for user ng processing\n");
+             "$$pattern and user too large for user ng processing\n");
     }
 
     item.key = keybuf;
@@ -61,19 +61,19 @@ static netgrp_u_compare(pattern, user)
     item.key = malloc(klen + 1);
     if (!item.key) {
         return Error(0, 0,
-           "%tout of memory for user ng processing\n");
+           "$$out of memory for user ng processing\n");
     }
     strcpy(item.key, keybuf);
     item.data = passed? YES: NO;
     if (!s_hsearch(HS_USER, item, ENTER)) {
         return Error(0, 0,
-           "%thash set failure for user ng processing\n");
+           "$$hash set failure for user ng processing\n");
     }
     return passed;
 }
 
 static int created_host_table = 0;
-static netgrp_h_compare(pattern, host)
+static int netgrp_h_compare(pattern, host)
   char *pattern;
   char *host;
 {
@@ -83,7 +83,7 @@ static netgrp_h_compare(pattern, host)
     if (!created_host_table) {
         if (!s_hcreate(HS_HOST, 1000)) {
 	    return Error(0, 0,
-		"%tCouldn't allocate hash table for host ng processing\n");
+		"$$Couldn't allocate hash table for host ng processing\n");
 	}
         created_host_table = 1;
     }
@@ -93,7 +93,7 @@ static netgrp_h_compare(pattern, host)
      */
     if (snprintf(keybuf, MAX_KEYLEN, "%s\n%s", pattern, host) >= MAX_KEYLEN) {
          return Error(0, 0,
-             "%tpattern and host too large for host ng processing\n");
+             "$$pattern and host too large for host ng processing\n");
     }
 
     item.key = keybuf;
@@ -108,13 +108,13 @@ static netgrp_h_compare(pattern, host)
     item.key = malloc(klen + 1);
     if (!item.key) {
         return Error(0, 0,
-           "%tout of memory for host ng processing\n");
+           "$$out of memory for host ng processing\n");
     }
     strcpy(item.key, keybuf);
     item.data = passed? YES: NO;
     if (!s_hsearch(HS_HOST, item, ENTER)) {
         return Error(0, 0,
-           "%thash set failure for host ng processing\n");
+           "$$hash set failure for host ng processing\n");
     }
     return passed;
 }
@@ -165,7 +165,7 @@ char *pat;	/* pattern that value must match */
      */
     if (s_re_comp(pat)) {
 	return Error(0, 0,
-	    "%t\n\tcheckenv(): couldn't compile pattern `%-.500s'.\n", pat);
+	    "$$\n\tcheckenv(): couldn't compile pattern `%-.500s'.\n", pat);
     }
 
     if (s_re_exec(value) != 1) {
@@ -229,7 +229,7 @@ before proceeding.\n", toupper(prog[0]), prog+1, localinfo.checkvar[0]);
 	    /* Ouch, checkvar=xxx is used, but xxx isn't defined! */
 	    fclose(prompt_fp);
 	    return Error(0, 0,
-		"%t\n\tError in super.tab file: \
+		"$$\n\tError in super.tab file: \
 `checkvar=%s' is used, but variable %s isn't defined!\n", varname, varname);
 	}
 
@@ -302,7 +302,7 @@ char *pat;	/* pattern that value must match */
     
     if (s_re_comp(pat)) {
 	return Error(0, 0,
-	    "%t\n\tcheck_value(): couldn't compile pattern `%-.500s'.\n", pat);
+	    "$$\n\tcheck_value(): couldn't compile pattern `%-.500s'.\n", pat);
     }
 
     if (s_re_exec(value) != 1) {
@@ -425,13 +425,13 @@ char *username;		/* name to translate */
 		pw = getpwuid(localinfo.file_uid);
 	    } else {
 		Error(0, 0,
-	    "%t: getpwentry() Internal Error!\n\tFile owner not yet known!\n");
+	    "$$: getpwentry() Internal Error!\n\tFile owner not yet known!\n");
 		return NULL;
 	    }
 	} else if (strcmp(username, "<caller>") == 0) {
 	    pw = &userinfo.caller;
 	} else {
-	    Error(0, 0, "%t\n\t\tUnknown special name %s\n", username);
+	    Error(0, 0, "$$\n\t\tUnknown special name %s\n", username);
 	    return NULL;
 	}
     } else {
@@ -446,7 +446,7 @@ char *username;		/* name to translate */
 	}
     }
     if (!pw) {
-	Error(0, 0, "%t\n\tNo such user or uid as `%s' in password file.\n",
+	Error(0, 0, "$$\n\tNo such user or uid as `%s' in password file.\n",
 	    username);
 	return NULL;
     }
@@ -480,7 +480,7 @@ char *name;		/* name to translate */
 	    gr = getgrgid(i);
     }
     if (!gr) {
-	Error(0, 0, "%t\n\tNo such group or gid as `%s'.\n", name);
+	Error(0, 0, "$$\n\tNo such group or gid as `%s'.\n", name);
 	return NULL;
     }
     return gr;
@@ -512,7 +512,7 @@ set_suppl_groups()
 	 * option groups=xxx, which is disallowed.
 	 */
 	if (localinfo.ngroups != GROUPS_NOTSET && !localinfo.groups_added)
-	    return Error(0, 0, "%t\n\t\tu+g=xxx conflicts with groups=yyy \
+	    return Error(0, 0, "$$\n\t\tu+g=xxx conflicts with groups=yyy \
 and may not be used in the same entry\n");
 
 	initgroups(localinfo.user, userinfo.new_gid);
@@ -530,10 +530,10 @@ and may not be used in the same entry\n");
 	}
 	ngroups = Getgroups(NGROUPS_MAX, gotten_groups);
 	if (ngroups == -1)
-	    return Error(1, 0, "%t Getgroups() failed: ");
+	    return Error(1, 0, "$$ Getgroups() failed: ");
 	if (ngroups + naddgroups > NGROUPS_MAX)
 	    return Error(1, 0,
-			    "%t\n\t\taddgroups=xxx adds too many groups.");
+			    "$$\n\t\taddgroups=xxx adds too many groups.");
 	for (i = 0; i < ngroups; i++)
 	    groups[i] = gotten_groups[i];
 	for (groups_p = &groups[ngroups], i=0; i < naddgroups; i++)
@@ -589,7 +589,7 @@ set_u_g()
 
 	if (found_gid == -1) {
 	    return Error(0, 0,
-	    "%t\n\tCan't set gid: no such group as `%s' in group file.\n",
+	    "$$\n\tCan't set gid: no such group as `%s' in group file.\n",
 		localinfo.group);
 	}
     }
@@ -598,7 +598,7 @@ set_u_g()
 
 	if (found_egid == -1) {
 	    return Error(0, 0,
-	    "%t\n\tCan't set egid: no such group as `%s' in group file.\n",
+	    "$$\n\tCan't set egid: no such group as `%s' in group file.\n",
 		localinfo.egroup);
 	}
     }
@@ -617,7 +617,7 @@ set_u_g()
 	uid_pw_name = strdup(pw->pw_name);
 	if (!uid_pw_name) 
 		return Error(0, 0,
-		    "%t\n\tfailed to malloc space for uid_pw_name=<%s>\n", pw->pw_name);
+		    "$$\n\tfailed to malloc space for uid_pw_name=<%s>\n", pw->pw_name);
 	
     }
     if (*localinfo.euser) {
@@ -628,7 +628,7 @@ set_u_g()
 	euid_pw_name = strdup(pw->pw_name);
 	if (!euid_pw_name)
 		return Error(0, 0,
-		    "%t\n\tfailed to malloc space for euid_pw_name=<%s>\n", pw->pw_name);
+		    "$$\n\tfailed to malloc space for euid_pw_name=<%s>\n", pw->pw_name);
     }
     if (*localinfo.u_g) {
 	pw = getpwentry(1, localinfo.u_g);
@@ -641,7 +641,7 @@ set_u_g()
     
     if (*localinfo.group && *localinfo.u_g) {
 	return Error(0, 0,
-		"%t\n\tCan't mix options gid=xxx and u+g=yyy in one entry.");
+		"$$\n\tCan't mix options gid=xxx and u+g=yyy in one entry.");
     }
 
     /*
@@ -1010,8 +1010,8 @@ get_setting()
 {
     if (sizeof(userinfo.salt) <= strlen(userinfo.encr)) {
 	return Error(0, 0, "Compilation error: the userinfo.salt field is too short (%d chars) to hold a copy of the userinfo.encr field (%d chars) for user %s",
-			sizeof(userinfo.salt), strlen(userinfo.encr),
-			userinfo.caller.pw_name);
+	    (int) sizeof(userinfo.salt), (int) strlen(userinfo.encr),
+	    userinfo.caller.pw_name);
     }
 
     if (userinfo.encr[0] == '$') {
@@ -1338,7 +1338,7 @@ char *salt;
 	Error(0, 1, "Failed to get password.\n");
     } else if (n >= sizeof(buf)) {
 	Error(0, 1, "Buffer too small (%d chars) to hold input password!\n",
-								sizeof(buf)-1);
+							(int) sizeof(buf)-1);
     }
 
 #ifdef _HPUX_SOURCE
@@ -1489,10 +1489,10 @@ int isglobal;		/* Is this a per-command or global condition? */
     /* Do brace globbing */
     if ((i=globbraces(s, 1, &globlist)) != 0) {
 	/* Local Condition */
-	return Error(0, 0, "%tMissing `%c'.\n", i);
+	return Error(0, 0, "$$Missing `%c'.\n", i);
     }
     if (balancedbraces(s) != 0) {
-	return Error(0, 0, "%tUnbalanced braces in %s.\n", s);
+	return Error(0, 0, "$$Unbalanced braces in %s.\n", s);
     }
 
     if (STRMATCH3("time", condition, s-1)) {
@@ -1508,7 +1508,7 @@ int isglobal;		/* Is this a per-command or global condition? */
 
     } else {
 	return Error(0, 0,
-		"%t\n\tInternal error: unrecognized condition <%s>.\n",
+		"$$\n\tInternal error: unrecognized condition <%s>.\n",
 		condition);
     }
     return 0;
@@ -1541,22 +1541,22 @@ int invert;	/* Inverts the test */
     if ((s=strchr(wd, '>')) || (s=strchr(wd, '<'))) {
 	if (s-wd == 4 && strncmp(wd, "time", 4) == 0) {
 	    return Error(0, 0,
-	    "%t\n\tPermittedUser patterns may not use '>' or '<';\n\
+	    "$$\n\tPermittedUser patterns may not use '>' or '<';\n\
 \tyou used '%s'; perhaps you meant to write 'time~%s'\n", wd, s);
 	} else {
 	    return Error(0, 0,
-	    "%t\n\tPermittedUser patterns may not use '>' or '<';\n\
+	    "$$\n\tPermittedUser patterns may not use '>' or '<';\n\
 \tyou used '%s'.\n", wd);
 	}
     }
     new = (SimpleList *) malloc(sizeof(SimpleList));
     if (!new)
-	return Error(0, 0, "%t\n\tFailed to malloc space for PermittedUser\n");
+	return Error(0, 0, "$$\n\tFailed to malloc space for PermittedUser\n");
     new->next = otl->next;
     new->pat = (char *) malloc(strlen(wd) + 1);
     if (!new->pat)
 	return Error(0, 0,
-		"%t\n\tFailed to malloc space for PermittedUser pat\n");
+		"$$\n\tFailed to malloc space for PermittedUser pat\n");
     strcpy(new->pat, wd);
     otl->next = new;
 
@@ -1564,13 +1564,13 @@ int invert;	/* Inverts the test */
 	new2 = (Simple2List *) malloc(sizeof(Simple2List));
 	if (!new2)
 	    return Error(0, 0,
-		"%t\n\tFailed to malloc space for PermittedUser\n");
+		"$$\n\tFailed to malloc space for PermittedUser\n");
 	new2->next = sl->next;
 	new2->other = otl->next;
 	new2->pat = (char *) malloc(strlen(tok) + (invert ? 2 : 1));
 	if (!new2->pat)
 	    return Error(0, 0,
-		"%t\n\tFailed to malloc space for PermittedUser pat\n");
+		"$$\n\tFailed to malloc space for PermittedUser pat\n");
 	if (invert) {
 	    *new2->pat = '!';
 	    strcpy(new2->pat+1, tok);
@@ -1678,7 +1678,7 @@ char *pattern;
 	/* Do brace globbing on the pattern */
 	wrap = (do_glob > 1) ? 1 : 0;
 	if ((i=globbraces(pattern, wrap, &patlist)) != 0) {
-	    Error(0, 0, "%tMissing `%c'.\n", i);
+	    Error(0, 0, "$$Missing `%c'.\n", i);
 	    return match;
 	}
     } else {
@@ -1687,7 +1687,7 @@ char *pattern;
 	patlist = pat1list;
     }
     if (balancedbraces(pattern) != 0) {
-	Error(0, 0, "%tUnbalanced braces in %s.\n", pattern);
+	Error(0, 0, "$$Unbalanced braces in %s.\n", pattern);
 	return match;
     }
 
@@ -1695,7 +1695,7 @@ char *pattern;
 	strcpy(tokbuf, tok);
 	anchor(tok, chkbuf);			/* Anchor all matches */
 	if ((*pat_compile)(chkbuf) != NULL) {
-	    Error(0, 0, "%t\n\tBad command pattern: `%s'.\n", pattern);
+	    Error(0, 0, "$$\n\tBad command pattern: `%s'.\n", pattern);
 	    return match;
 
 	} else if ((*pat_compare)(str) == 1) {
@@ -1730,15 +1730,15 @@ char *token;		/* user/group/host pattern */
     int match, i;
 
     if (strlen(token) > sizeof(chkbuf)-4) {
-	return Error(0, 1, "%tCan't handle patterns larger than %d chars.\n",
-		sizeof(chkbuf)-4);
+	return Error(0, 1, "$$Can't handle patterns larger than %d chars.\n",
+		(int) sizeof(chkbuf)-4);
     }
 
     /* Split into user:group@host; check host part first (if it exists) */
     if ((hostpat = strchr(token, '@'))) {
 	if (hostpat[1] == 0) {
 	    return Error(0, 0,
-	    	"%tMissing hostname in pattern `%s'.\n", origtext);
+	    	"$$Missing hostname in pattern `%s'.\n", origtext);
 	}
 	*hostpat++ = 0;
  
@@ -1748,19 +1748,19 @@ char *token;		/* user/group/host pattern */
 #ifdef HAVE_INNETGR
 	    if (hostpat[1] == 0) {
 		return Error(0, 0,
-			"%tMissing netgroupname in pattern `%s'.\n", origtext);
+			"$$Missing netgroupname in pattern `%s'.\n", origtext);
 	    }
 	    match = check_host(hostpat, userinfo.hostname);
 #else
 	    return Error(0, 0, 
-	"%thostnames may not begin with `+' since this super() was compiled\n\
+	"$$hostnames may not begin with `+' since this super() was compiled\n\
 without -DHAVE_INNETGR.\n");
 #endif
 	} else {
 	    strtolower(hostpat);
 	    anchor(hostpat, chkbuf);    /* Force all matches to be anchored */
 	    if ((*pat_compile)(chkbuf) != NULL) {
-		return Error(0, 0, "%tbad host pattern: `%s'.\n", origtext);
+		return Error(0, 0, "$$bad host pattern: `%s'.\n", origtext);
 	    }
 	}
  
@@ -1781,7 +1781,7 @@ without -DHAVE_INNETGR.\n");
     userpat = token;
     if (*token == '\0' && !hostpat) {
 	/* Nothing in pattern?! */
-	return Error(0, 0, "%t\n\tUnacceptable pattern `%s'.\n", origtext);
+	return Error(0, 0, "$$\n\tUnacceptable pattern `%s'.\n", origtext);
 
     } else if (*token == '\0') {
 	userpat = grouppat = "^.*$";		/* only hostname given */
@@ -1797,12 +1797,12 @@ without -DHAVE_INNETGR.\n");
 	grouppat = "^.*$";
     }
     if (strchr(grouppat, ':')) {
-	return Error(0, 0, "%t\n\tGroup pattern `%s' contains a colon!\n",
+	return Error(0, 0, "$$\n\tGroup pattern `%s' contains a colon!\n",
 			grouppat);
     }
 
     if (globalinfo.group_slash == 0 && strchr(grouppat, '/')) {
-	return Error(0, 0, "%t\n\tFormat error in super.tab file: \
+	return Error(0, 0, "$$\n\tFormat error in super.tab file: \
 group pattern `%s' contains a slash.\n\
 \tPerhaps you meant to use Cmd::Filename, but forgot one colon,\n\
 \tso it looks like User:Group?  If you really need to allow\n\
@@ -1814,7 +1814,7 @@ group pattern `%s' contains a slash.\n\
     if (userpat[0] == '+') {
 	if (userpat[1] == 0) {
 	    return Error(0, 0,
-			"%tMissing netgroupname in pattern `%s'.\n", origtext);
+			"$$Missing netgroupname in pattern `%s'.\n", origtext);
 	}
 	match = netgrp_u_compare(&userpat[1], userinfo.caller.pw_name);
     } else
@@ -1822,7 +1822,7 @@ group pattern `%s' contains a slash.\n\
     {
 	anchor(userpat, chkbuf);		/* Anchor all matches */
 	if ((*pat_compile)(chkbuf) != NULL) {
-	    return Error(0, 0, "%t\n\tbad user pattern: `%s'.\n", origtext);
+	    return Error(0, 0, "$$\n\tbad user pattern: `%s'.\n", origtext);
 	}
 	match = (*pat_compare)(userinfo.caller.pw_name);
 #ifdef MATCH_DECIMAL_UID
@@ -1851,7 +1851,7 @@ group pattern `%s' contains a slash.\n\
     anchor(grouppat, chkbuf);
     i = ingroup(userinfo.caller.pw_name, userinfo.caller.pw_gid, chkbuf);
     if (i == -1)
-	return Error(0, 0, "%t\n\tbad group pattern\n", origtext);
+	return Error(0, 0, "$$\n\tbad group pattern <%s>\n", origtext);
 
     if (debug > 1)
 	fprintf(stderr,
@@ -1909,7 +1909,7 @@ char *gp_pat;	/* pattern to match */
     if (!created_group_table) {
         if (!s_hcreate(HS_GROUP, 1000)) {
 	    return Error(0, 0,
-		"%tCouldn't allocate hash table for group processing\n");
+		"$$Couldn't allocate hash table for group processing\n");
 	}
         created_group_table = 1;
     }
@@ -1920,7 +1920,7 @@ char *gp_pat;	/* pattern to match */
     if (snprintf(keybuf, MAX_KEYLEN, "%s\n%d\n%s", user, gid, gp_pat)
              >= MAX_KEYLEN) {
          return Error(0, 0,
-             "%tuser/gid/gp_pat too large for user ng processing\n");
+             "$$user/gid/gp_pat too large for user ng processing\n");
     }
 
     item.key = keybuf;
@@ -2005,13 +2005,13 @@ found_it:
     item.key = malloc(klen + 1);
     if (!item.key) {
         return Error(0, 0,
-           "%tout of memory for group processing\n");
+           "$$out of memory for group processing\n");
     }
     strcpy(item.key, keybuf);
     item.data = passed? YES: NO;
     if (!s_hsearch(HS_GROUP, item, ENTER)) {
         return Error(0, 0,
-           "%thash set failure for group processing\n");
+           "$$hash set failure for group processing\n");
     }
     return passed;
 }
