@@ -1,4 +1,4 @@
-static const char rcsid[] = "$Id: error.c,v 1.79 2007/03/07 00:23:27 will Exp will $";
+static const char rcsid[] = "$Id: error.c,v 1.80 2020/08/03 17:13:04 will Exp $";
 
 /*
  *	Copyright (c) 1993 by California Institute of Technology.
@@ -98,7 +98,7 @@ static const char rcsid[] = "$Id: error.c,v 1.79 2007/03/07 00:23:27 will Exp wi
  *	between messages.
 
  * If error_tag is !0, or if the _first_ two characters of the output
- *	format are "%t", then the output is preceded with a message like
+ *	format are "%t" or "$$", then the output is preceded with a message like
  *	the following:
  *  (a) error_srcfile == NULL:
  *	""				# error_line <= 0
@@ -120,8 +120,8 @@ static const char rcsid[] = "$Id: error.c,v 1.79 2007/03/07 00:23:27 will Exp wi
  *	the program name is _not_ suffixed with ":" -- that way, the
  *	output looks something like:
  *		progxyz (lines 232..255 in file `.......'): errmsg
- *	2. In the event that the first two characters are "%t", they enable
- *	tagline printing but are not printed.
+ *	2. In the event that the first two characters are "%t" or "$$",
+ *	they enable tagline printing but are not printed.
 
  * Return code is -1, so you can print error messages and return an error
  *	code with   return Error(...);
@@ -236,7 +236,7 @@ Error(
     error_counter++;
 
     /* Figure out line tagging */
-    pctt = strncmp(fmt, "%t", 2) == 0;
+    pctt = (strncmp(fmt, "%t", 2) == 0 || strncmp(fmt, "$$", 2) == 0);
     tag = ( pctt || error_tag ) ? taglines(3) : NULL;
     if (pctt)
 	fmt += 2;
@@ -387,7 +387,7 @@ va_dcl
     die = va_arg(ap, int);
     fmt = va_arg(ap, char *);
     va_end(ap);
-    pctt = strncmp(fmt, "%t", 2) == 0;
+    pctt = (strncmp(fmt, "%t", 2) == 0 || strncmp(fmt, "$$", 2) == 0);
     tag = ( pctt || error_tag ) ? taglines(3) : NULL;
     if (pctt)
 	fmt += 2;
