@@ -90,6 +90,10 @@ char *strdup P__((char *));
 #include <sys/bsdtypes.h>
 #endif
 
+#ifdef HAVE_POSIX_REGEX
+#include <regex.h>
+#endif
+
 #ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
 #else
@@ -188,6 +192,23 @@ int misc_conv(int num_msg, const struct pam_message **msgm,
 #endif
 #endif
 
+#ifdef HAVE_SYS_IOCTL_H
+#include <sys/ioctl.h>
+#endif
+
+/* Want just one of termios.h, termio.h, sgtty.h */
+#ifdef HAVE_TERMIOS_H
+#include <termios.h>
+#else
+#ifdef HAVE_TERMIO_H
+#include <termio.h>
+#else
+#ifdef HAVE_SGTTY_H
+#include <sgtty.h>
+#endif
+#endif
+#endif
+
 #ifdef HAVE_PROT_H
 #include <prot.h>
 #endif
@@ -229,6 +250,10 @@ extern int gethostname P__((char *, size_t size));
 #endif
 #endif
 
+#ifdef HAVE_SYS_SYSINFO_H
+#include <sys/sysinfo.h>
+#endif
+
 #ifdef HAVE_SYS_SYSTEMINFO_H
 #include <sys/systeminfo.h>
 extern int sysinfo();
