@@ -1,4 +1,4 @@
-static const char rcsid[] = "$Id: options.c,v 1.131 2007/03/07 15:00:20 will Exp $";
+static const char rcsid[] = "$Id: options.c,v 1.132 2020/08/03 17:13:04 will Exp $";
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /* Process a global xxx=yyy option */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -116,7 +116,7 @@ char *word;
 	wordlen = 3;
     } else if (!(sep = strchr(word, OPTION_SEP))) {
 	Error(0, 0,
-		"%t\n\tsuper.tab option `%s' is missing separator `%c'\n",
+		"$$\n\tsuper.tab option `%s' is missing separator `%c'\n",
 		word, OPTION_SEP);
 	return NULL;
     } else {
@@ -169,7 +169,7 @@ int isglobal;	/* bool: are we processing a global or local entry? */
 
     if (*word == '!') {
 	DoDebug();
-	return Error(0, 0, "%t\n\tsuper.tab syntax error: \n\
+	return Error(0, 0, "$$\n\tsuper.tab syntax error: \n\
 options cannot be negated: <%s>\n", word);
     }
 
@@ -179,12 +179,12 @@ options cannot be negated: <%s>\n", word);
 	if (isglobal && !(opt->flags & GLOBAL)) {
 	    DoDebug();
 	    return Error(0, 0,
-		    "%t\n\t`%s' may not be used as a global option\n", word);
+		    "$$\n\t`%s' may not be used as a global option\n", word);
 	}
 	if (!isglobal && !(opt->flags & LOCAL)) {
 	    DoDebug();
 	    return Error(0, 0,
-		    "%t\n\t`%s' may not be used as a local option\n", word);
+		    "$$\n\t`%s' may not be used as a local option\n", word);
 	}
 
 	if (opt->flags & LIST) {
@@ -193,12 +193,12 @@ options cannot be negated: <%s>\n", word);
 	    int i;
 
 	    if (balancedbraces(value) != 0) {
-		return Error(0, 0, "%tUnbalanced braces in `%s'.\n", value);
+		return Error(0, 0, "$$Unbalanced braces in `%s'.\n", value);
 	    }
 	    if ((i=globbraces(value, 1, &globlist)) != 0) {
 		/* Option argument */
 		DoDebug();
-		return Error(0, 0, "%tMissing `%c'.\n", i);
+		return Error(0, 0, "$$Missing `%c'.\n", i);
 	    }
 	    optionlist = globlist;
 	}
@@ -207,12 +207,12 @@ options cannot be negated: <%s>\n", word);
     } else {
 	DoDebug();
 	if (value-word == 5 && strncmp(word, "time", 4) == 0) {
-	    return Error(0, 0, "%t\n\tUnrecognized %s option `%s'.\n\
+	    return Error(0, 0, "$$\n\tUnrecognized %s option `%s'.\n\
 \tPerhaps you meant to use the condition `time~%s'?\n",
 			isglobal ? "global" : "local", word, value);
 	} else {
 	    return Error(0, 0,
-			"%t\n\tInvalid %s option `%s'.\n",
+			"$$\n\tInvalid %s option `%s'.\n",
 			isglobal ? "global" : "local", word);
 	}
     }
@@ -306,7 +306,7 @@ option_local_clear_settings()
 	localinfo.fd = (int *) malloc(sizeof(int) * (maxfd + 1));
 	if (!localinfo.fd)
 	    return Error(1, 0,
-		"%t\n\tFailed to malloc space for file descriptor list: ");
+		"$$\n\tFailed to malloc space for file descriptor list: ");
     }
     for (i=0; i<=maxfd; i++) {
 	localinfo.fd[i] = 0;
@@ -381,12 +381,12 @@ int isglobal;
     } else if (strcmp(s, "n") == 0) {
 	required = 0;
     } else {
-	return Error(0, 0, "%t\n\tInvalid option value \
+	return Error(0, 0, "$$\n\tInvalid option value \
 in `%s' -- value must be `y' or `n'\n", word);
     }
 
     if (required && using_user_supertab) {
-	return Error(0, 0, "%t\n\tUser-supplied .supertab files may not do \
+	return Error(0, 0, "$$\n\tUser-supplied .supertab files may not do \
 authentication checking -- sorry.\n");
     }
 
@@ -411,14 +411,14 @@ int isglobal;
 				s, isglobal ? "global" : "local");
 
     if (using_user_supertab) {
-	return Error(0, 0, "%t\n\tUser-supplied .supertab files may not do \
+	return Error(0, 0, "$$\n\tUser-supplied .supertab files may not do \
 password checking -- sorry.\n");
     }
 
     str = strdup(s);
     if (!str)
 	return Error(0, 0,
-		    "%t\n\tfailed to malloc space for authprompt=<%s>\n", s);
+		    "$$\n\tfailed to malloc space for authprompt=<%s>\n", s);
     if (isglobal)
 	globalinfo.authinfo.prompt = str;
     else
@@ -444,7 +444,7 @@ int isglobal;
     } else if (strcmp(s, "password") == 0) {
 	method = SUPER_AUTH_PASSWORD;
     } else {
-	return Error(0, 0, "%t\n\tInvalid option value \
+	return Error(0, 0, "$$\n\tInvalid option value \
 in `%s' -- value must be `pam' or `password'\n", word);
     }
 
@@ -468,7 +468,7 @@ int isglobal;
 
     /* Don't do any logging if debugging or just checking syntax! */
     if (check_syntax || it_came_from_cmdline) {
-	Error(0, 0, "%t\n\tIgnoring authuser option, due to debug mode\n");
+	Error(0, 0, "$$\n\tIgnoring authuser option, due to debug mode\n");
 	return 0;
     }
 
@@ -519,15 +519,15 @@ int isglobal;
 
     if (i != 3 || eq != OPTION_SEP || iarg1 <= 0 || iarg2 < iarg1)
 	return Error(0, 0,
-		"%t\n\tImproper use of argNNN%cXXX option\n", OPTION_SEP);
+		"$$\n\tImproper use of argNNN%cXXX option\n", OPTION_SEP);
 
     /* Put pattern into the argpat list. */
     {
 	char buf[500];
 	if (strlen(pat) > sizeof(buf)-3)
 	    return Error(0, 0,
-			    "%t\n\tArgument pattern <%s> too long (max %d)\n",
-			    pat, sizeof(buf)-3);
+			    "$$\n\tArgument pattern <%s> too long (max %d)\n",
+			    pat, (int) sizeof(buf)-3);
 	anchor(pat, buf);
 	if (ARinsert(argpats, iarg1, iarg2, buf) == -1) {
 	    return Error(0, 0,
@@ -609,7 +609,7 @@ int isglobal;
 
     localinfo.die = strdup(s);
     if (!localinfo.die)
-	return Error(0, 0, "%t\n\tfailed to malloc space for die=<%s>\n", s);
+	return Error(0, 0, "$$\n\tfailed to malloc space for die=<%s>\n", s);
     return 0;
 }
 
@@ -672,7 +672,7 @@ int isglobal;
 
     i = sscanf(s, "%d", &m);
     if (i != 1) {
-	return Error(0, 0, "%t\n\tmaxenvlen must be maxenvlen=nnn.\n", word);
+	return Error(0, 0, "$$\n\tmaxenvlen must be maxenvlen=nnn; you used <%s>.\n", word);
     }
     if (isglobal) {
 	globalinfo.maxenvlen = m;
@@ -707,7 +707,7 @@ int isglobal;
 	    localinfo.fd[n] = 1;
 	else
 	    return Error(0, 0,
-		"%t\n\tRidiculous value in file descriptor list: `%s'\n",
+		"$$\n\tRidiculous value in file descriptor list: `%s'\n",
 		word);
     }
     blkfree(optionlist);
@@ -743,7 +743,7 @@ int isglobal;
     } else {
 	globalinfo.group_slash = 1;
 	if (strcmp(s, "y") != 0)
-	    return Error(0, 0, "%t\n\tInvalid option value \
+	    return Error(0, 0, "$$\n\tInvalid option value \
 in `%s' -- value must be `y' or `n'\n", word);
     }
     return 0;
@@ -785,7 +785,7 @@ int isglobal;
     } else if (strcmp(word, "addgroups") != 0) {
 	is_addgroups = 1;
     } else {
-	return Error(0, 0, "%tInternal error:\n\
+	return Error(0, 0, "$$Internal error:\n\
 \tDon't know what to do when option isn't groups or addgroups!\n");
     }
 
@@ -799,7 +799,7 @@ int isglobal;
 	localinfo.groups_added = is_addgroups;
     }
     if (*ngroups_p != GROUPS_NOTSET)
-	return Error(0, 0, "%t\n\t\tCan't have multiple addgroups=xxx and/or \
+	return Error(0, 0, "$$\n\t\tCan't have multiple addgroups=xxx and/or \
 groups=xxx options in one entry\n");
 
     for (*ngroups_p = 0, iwd=0; (wd=optionlist[iwd]); iwd++) {
@@ -807,7 +807,7 @@ groups=xxx options in one entry\n");
 	if (i == -1) {
 	    *ngroups_p = 0;
 	    return Error(0, 0,
-	    "%t\n\tCan't set gid: no such group as `%s' in group file.\n", wd);
+	    "$$\n\tCan't set gid: no such group as `%s' in group file.\n", wd);
 
 	} else {
 	    *group_p++ = (GETGROUPS_T) i;
@@ -815,8 +815,8 @@ groups=xxx options in one entry\n");
 	}
     }
     blkfree(optionlist);
-    return (wd) ? Error(0, 0, "%t\n\ttoo many supplementary \
-groups (max=%d) in option %s=...", word) : 0;
+    return (wd) ? Error(0, 0, "$$\n\ttoo many supplementary \
+groups (max=?) in option %s=...", word) : 0;
 }
 #endif
 
@@ -848,12 +848,12 @@ int isglobal;
 				s, isglobal ? "global" : "local");
 
 #ifndef HAVE_LOCALE_H
-    return Error(0, 0, "%t\n\tOption `lang' isn't supported on this host, \
+    return Error(0, 0, "$$\n\tOption `lang' isn't supported on this host, \
 because the locale functions aren't available\n");
 #endif
 
     if (!setlocale(LC_TIME, s))
-	return Error(0, 0, "%t\n\tCan't set time locale to `%s'.  \
+	return Error(0, 0, "$$\n\tCan't set time locale to `%s'.  \
 No such locale?\n", s);
 
     /* Update the list of day names */
@@ -874,7 +874,7 @@ int isglobal;
 
     /* Don't do any logging if debugging or just checking syntax! */
     if (check_syntax || it_came_from_cmdline) {
-	Error(0, 0, "%t\n\tIgnoring logfile option, due to debug mode\n");
+	Error(0, 0, "$$\n\tIgnoring logfile option, due to debug mode\n");
 	return 0;
     }
 
@@ -895,7 +895,7 @@ int isglobal;
 
     /* Don't do any logging if debugging or just checking syntax! */
     if (check_syntax || it_came_from_cmdline) {
-	Error(0, 0, "%t\n\tIgnoring loguid option, due to debug mode\n");
+	Error(0, 0, "$$\n\tIgnoring loguid option, due to debug mode\n");
 	return 0;
     }
 
@@ -920,18 +920,18 @@ int isglobal;
 
     if (isglobal) {
 	if (strlen(s) > sizeof(globalinfo.mailcmd)-1)
-	    return Error(0, 0, "%t\n\tRidiculous length of string: `%s'.\n\
+	    return Error(0, 0, "$$\n\tRidiculous length of string: `%s'.\n\
 \tMaximum permitted length is %d; the entry used %d\n",
-		word, sizeof(globalinfo.mailcmd)-1, strlen(s));
+		word, (int) sizeof(globalinfo.mailcmd)-1, (int) strlen(s));
 
 	strcpy(globalinfo.mailcmd, s);
 	error_command = globalinfo.mailcmd;
 	globalinfo.mail_success = 0;
     } else {
 	if (strlen(s) > sizeof(localinfo.mailcmd)-1)
-	    return Error(0, 0, "%t\n\tRidiculous length of string: `%s'.\n\
+	    return Error(0, 0, "$$\n\tRidiculous length of string: `%s'.\n\
 \tMaximum permitted length is %d; the entry used %d\n",
-		word, sizeof(localinfo.mailcmd)-1, strlen(s));
+		word, (int) sizeof(localinfo.mailcmd)-1, (int) strlen(s));
 
 	strcpy(localinfo.mailcmd, s);
 	error_command = localinfo.mailcmd;
@@ -956,18 +956,18 @@ int isglobal;
 
     if (isglobal) {
 	if (strlen(s) > sizeof(globalinfo.mailcmd)-1)
-	    return Error(0, 0, "%t\n\tRidiculous length of string: `%s'.\n\
+	    return Error(0, 0, "$$\n\tRidiculous length of string: `%s'.\n\
 \tMaximum permitted length is %d; the entry used %d\n",
-		word, sizeof(globalinfo.mailcmd)-1, strlen(s));
+		word, (int) sizeof(globalinfo.mailcmd)-1, (int) strlen(s));
 
 	strcpy(globalinfo.mailcmd, s);
 	error_command = globalinfo.mailcmd;
 	globalinfo.mail_success = 1;
     } else {
 	if (strlen(s) > sizeof(localinfo.mailcmd)-1)
-	    return Error(0, 0, "%t\n\tRidiculous length of string: `%s'.\n\
+	    return Error(0, 0, "$$\n\tRidiculous length of string: `%s'.\n\
 \tMaximum permitted length is %d; the entry used %d\n",
-		word, sizeof(localinfo.mailcmd)-1, strlen(s));
+		word, (int) sizeof(localinfo.mailcmd)-1, (int) strlen(s));
 
 	strcpy(localinfo.mailcmd, s);
 	error_command = localinfo.mailcmd;
@@ -1003,7 +1003,7 @@ int isglobal;
 		break;
     default:
 	return Error(0, 0,
-		"%t\n\tnargs must be nargs=nnn or  nargs=mmm-nnn.\n", word);
+		"$$\n\tnargs must be nargs=nnn or  nargs=mmm-nnn; you used <%s>\n", word);
     }
     return 0; 
 }
@@ -1030,7 +1030,7 @@ int isglobal;
 	break;
     default:
 	return Error(0, 0,
-	    "%t\n\tmaxlen must be maxlen=nnn or  maxlen=mmm,nnn.\n", word);
+	    "$$\n\tmaxlen must be maxlen=nnn or  maxlen=mmm,nnn; you used <%s>\n", word);
     }
     if (isglobal) {
 	globalinfo.maxlen1arg = m;
@@ -1057,7 +1057,7 @@ int isglobal;
 
     nice_incr = strtol(s, &p, 0);
     if (p == word)
-	return Error(0, 0, "%t\n\tillegal value in `nice=%s'\n", word);
+	return Error(0, 0, "$$\n\tillegal value in `nice=%s'\n", word);
     store_nice_incr(nice_incr, isglobal);
     return 0;
 }
@@ -1096,12 +1096,12 @@ int isglobal;
     } else {
 	required = 1;
 	if (strcmp(s, "y") != 0)
-	    return Error(0, 0, "%t\n\tInvalid option value \
+	    return Error(0, 0, "$$\n\tInvalid option value \
 in `%s' -- value must be `y' or `n'\n", word);
     }
 
     if (required && using_user_supertab) {
-	return Error(0, 0, "%t\n\tUser-supplied .supertab files may not do \
+	return Error(0, 0, "$$\n\tUser-supplied .supertab files may not do \
 password checking -- sorry.\n");
     }
 
@@ -1143,14 +1143,14 @@ int isglobal;
 	char *buf = strdup(pat_name);
 	if (!buf) {
 	    return Error(0, 0,
-		"%t\n\tCan't malloc space for copy of <%s>\n", pat_name);
+		"$$\n\tCan't malloc space for copy of <%s>\n", pat_name);
 	}
 	/* Check the options: we allow:
 	 *	posix[/extended][/icase]
 	 */
 	p = strtok(buf, "/");
 	if (strcmp(p, "posix") != 0) {
-	    return Error(0, 0, "%t\n\tInternal error: got pat type <%s> when altready checked it's simply `posix'!\n", p);
+	    return Error(0, 0, "$$\n\tInternal error: got pat type <%s> when altready checked it's simply `posix'!\n", p);
 	}
 	for (p=strtok(NULL, "/"); p; p=strtok(NULL, "/")) {
 	    if (strcmp(p, "extended") == 0) {
@@ -1159,7 +1159,7 @@ int isglobal;
 		p_regcomp_flags(REG_ICASE);
 	    } else {
 		return Error(0, 0,
-			    "%t\n\tUnknown posix pattern variant `%s'.\n", p);
+			    "$$\n\tUnknown posix pattern variant `%s'.\n", p);
 	    }
 	}
 	free(buf);
@@ -1169,10 +1169,10 @@ int isglobal;
 #endif
     } else {
 #ifdef HAVE_POSIX_REGEX
-	return Error(0, 0, "%t\n\tInvalid pattern type `%s'.  \
+	return Error(0, 0, "$$\n\tInvalid pattern type `%s'.  \
 Valid: \"shell\", \"regex\", and \"posix[/extended][/icase]\"\n", pat_name);
 #else
-	return Error(0, 0, "%t\n\tInvalid pattern type `%s'.  \
+	return Error(0, 0, "$$\n\tInvalid pattern type `%s'.  \
 Valid: \"shell\" and \"regex\"\n", pat_name);
 #endif
     }
@@ -1192,7 +1192,7 @@ int isglobal;
 
     localinfo.print = strdup(s);
     if (!localinfo.print)
-	return Error(0, 0, "%t\n\tfailed to malloc space for print=<%s>\n", s);
+	return Error(0, 0, "$$\n\tfailed to malloc space for print=<%s>\n", s);
     return 0;
 }
 
@@ -1211,7 +1211,7 @@ int isglobal;
     } else {
 	globalinfo.relative_path = 1;
 	if (strcmp(s, "y") != 0)
-	    return Error(0, 0, "%t\n\tInvalid option value \
+	    return Error(0, 0, "$$\n\tInvalid option value \
 in `%s' -- value must be `y' or `n'\n", word);
     }
     return 0;
@@ -1232,7 +1232,7 @@ int isglobal;
     } else {
 	globalinfo.authinfo.renewtime = 0;
 	if (strcmp(s, "n") != 0)
-	    return Error(0, 0, "%t\n\tInvalid option value \
+	    return Error(0, 0, "$$\n\tInvalid option value \
 in `%s' -- value must be `y' or `n'\n", word);
     }
     return 0; 
@@ -1249,12 +1249,12 @@ int isglobal;
 				s, isglobal ? "global" : "local");
 
 #ifndef USE_RSYSLOG
-    return Error(0, 0, "%t\n\tOption rlog_host is not allowed, because \
+    return Error(0, 0, "$$\n\tOption rlog_host is not allowed, because \
 this copy of super was compiled with rsyslog disabled.\n");
 #endif
 
     if (*s == '\0')
-	return Error(0, 0, "%t\n\tInvalid option value in `%s' \
+	return Error(0, 0, "$$\n\tInvalid option value in `%s' \
 -- empty value not allowed.\n", word);
 
     error_rlog_host = strdup(s);
@@ -1277,7 +1277,7 @@ int isglobal;
     /* s must have form v=xxx, where v is any string not including `='. */
     if (*s == '=' || !strchr(s+1, '='))
 	return Error(0, 0,
-	"%t\n\tbad syntax for setenv%cvar=xxx; you used `setenv%c%s'.\n",
+	"$$\n\tbad syntax for setenv%cvar=xxx; you used `setenv%c%s'.\n",
 	OPTION_SEP, OPTION_SEP, s);
 
     /* Append this variable: first skip past already-set variables... */
@@ -1287,7 +1287,7 @@ int isglobal;
 	/* ...then add this definition */
 	if (i == MAXSETENV) {
 	    return Error(0, 0,
-		"%t\n\ttoo many global setenv%cvar=xxx entries; max is %d.\n",
+		"$$\n\ttoo many global setenv%cvar=xxx entries; max is %d.\n",
 		OPTION_SEP, MAXSETENV);
 	} else {
 	    char *t = strdup(s);
@@ -1304,7 +1304,7 @@ int isglobal;
 	/* ...then add this definition */
 	if (i == MAXSETENV) {
 	    return Error(0, 0,
-		"%t\n\ttoo many local setenv%cvar=xxx entries; max is %d.\n",
+		"$$\n\ttoo many local setenv%cvar=xxx entries; max is %d.\n",
 		OPTION_SEP, MAXSETENV);
 	} else {
 	    char *t = strdup(s);
@@ -1337,10 +1337,10 @@ int isglobal;
     } else {
 	error_syslog = 1;
 	if (strcmp(s, "y") != 0)
-	    return Error(0, 0, "%t\n\tInvalid option value in `%s' \
+	    return Error(0, 0, "$$\n\tInvalid option value in `%s' \
 -- value must be `y' or `n'.\n", word);
 #ifndef HAVE_SYSLOG
-	return Error(0, 0, "%t\n\tCan't use option syslog -- \
+	return Error(0, 0, "$$\n\tCan't use option syslog -- \
 not compiled with HAVE_SYSLOG defined.\n");
 #endif
     }
@@ -1360,7 +1360,7 @@ int isglobal;
 				s, isglobal ? "global" : "local");
 
 #ifndef HAVE_SYSLOG
-	return Error(0, 0, "%t\n\tCan't use option syslog_error -- \
+	return Error(0, 0, "$$\n\tCan't use option syslog_error -- \
 not compiled with HAVE_SYSLOG defined.\n");
 #endif
 
@@ -1385,7 +1385,7 @@ int isglobal;
 				s, isglobal ? "global" : "local");
 
 #ifndef HAVE_SYSLOG
-	return Error(0, 0, "%t\n\tCan't use option syslog_success -- \
+	return Error(0, 0, "$$\n\tCan't use option syslog_success -- \
 not compiled with HAVE_SYSLOG defined.\n");
 #endif
 
@@ -1431,7 +1431,7 @@ int isglobal;
 	globalinfo.authinfo.perhost = 1;
     } else {
 	return Error(0, 0,
-		"%t\n\tInvalid option value in `%s' -- \
+		"$$\n\tInvalid option value in `%s' -- \
 value must be `y' or `n'.\n", word);
     }
     return 0;
@@ -1496,12 +1496,11 @@ int isglobal;
 	mask = userinfo.orig_mask;
     } else if (strcmp(s, "<owner>") == 0) {
 	return Error(0, 0,
-	    "%t\n\tThe <owner> value isn't allowed in the umask=xxx option\n",
-	    word);
+	    "$$\n\tThe <owner> value isn't allowed in the umask=xxx option\n");
     } else {
 	mask = strtol(s, &p, 0);
 	if (mask < 0 || p == word)
-	    return Error(0, 0, "%t\n\tillegal value in `%s'\n", word);
+	    return Error(0, 0, "$$\n\tillegal value in `%s'\n", word);
     }
 
     store_umask(mask, isglobal);
@@ -1523,7 +1522,7 @@ int isglobal;
     } else {
 	globalinfo.gethostbyname = 1;
 	if (strcmp(s, "y") != 0)
-	    return Error(0, 0, "%t\n\tInvalid option value \
+	    return Error(0, 0, "$$\n\tInvalid option value \
 in `%s' -- value must be `y' or `n'\n", word);
     }
     return 0;
