@@ -35,7 +35,9 @@ static int option_authuser	P__(( char *word, char *s, int isglobal ));
 static int option_cd		P__(( char *word, char *s, int isglobal ));
 static int option_checkvar	P__(( char *word, char *s, int isglobal ));
 static int option_die		P__(( char *word, char *s, int isglobal ));
+static int option_egid		P__(( char *word, char *s, int isglobal ));
 static int option_env		P__(( char *word, char *s, int isglobal ));
+static int option_euid		P__(( char *word, char *s, int isglobal ));
 static int option_fd		P__(( char *word, char *s, int isglobal ));
 static int option_gethostbyname	P__(( char *word, char *s, int isglobal ));
 static int option_gid		P__(( char *word, char *s, int isglobal ));
@@ -57,7 +59,9 @@ static int option_patterns	P__(( char *word, char *s, int isglobal ));
 static int option_print		P__(( char *word, char *s, int isglobal ));
 static int option_relative_path	P__(( char *word, char *s, int isglobal ));
 static int option_renewtime	P__(( char *word, char *s, int isglobal ));
+/* static int option_rgid		P__(( char *word, char *s, int isglobal )); */
 static int option_rlog_host	P__(( char *word, char *s, int isglobal ));
+/* static int option_ruid		P__(( char *word, char *s, int isglobal )); */
 static int option_setenv	P__(( char *word, char *s, int isglobal ));
 static int option_syslog	P__(( char *word, char *s, int isglobal ));
 static int option_syslog_error	P__(( char *word, char *s, int isglobal ));
