@@ -1,10 +1,15 @@
-static char rcsid[] = "$Id: s_re_fail.c,v 1.5 1998/03/02 06:53:59 will Exp $";
+static const char rcsid[] = "$Id: s_re_fail.c,v 1.6 2004/04/30 17:00:58 will Exp $";
 #ifdef vms
 #include stdio
 #else
 #include <stdio.h>
 #endif
 
+#include "config.h"
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+
 /* 
  * s_re_fail:
  *	internal error handler for s_re_exec.
