@@ -1,4 +1,4 @@
-static const char rcsid[] = "$Id: super.c,v 1.613 2007/12/20 19:14:30 will Exp $";
+static const char rcsid[] = "$Id: super.c,v 1.615 2020/08/03 17:13:04 will Exp $";
 /* The code should compile with either ANSI C or K&R compilers. */
 
 /*
@@ -683,7 +683,7 @@ char **o_file, **r_path;
 		}
 		if (strlen(mhost) > sizeof(userinfo.hostname)-1)
 		    Error(0, 1, "Machine name too long -- max allowed is %d\n",
-				sizeof(userinfo.hostname)-1);
+				(int) sizeof(userinfo.hostname)-1);
 		strcpy(userinfo.hostname, mhost);
 		if (canonicalize_hostname(userinfo.hostname,
 					    sizeof(userinfo.hostname)) == -1)
@@ -849,7 +849,7 @@ by `-o %s' is overridden by file `%s'", *o_file, superfile);
 		     * to the real uid.
 		     */
 		    if (getuid() != 0) {
-			setuid(getuid());
+			(void) setuid(getuid());
 			fprintf(stderr,
     "\t** Since you have supplied a super.tab file that isn't the default,\n");
 			fprintf(stderr,
@@ -1163,7 +1163,7 @@ char *user;
 	    strlen(PERUSER_SUPERFILE) + 1) > sizeof(superfile_writable))
 	Error(0, 1,
 		"User %s's <home directory>+<%s> pathlen exceeds %d?!\n",
-		user, PERUSER_SUPERFILE, sizeof(superfile_writable));
+		user, PERUSER_SUPERFILE, (int) sizeof(superfile_writable));
     (void) strcpy(superfile, pass->pw_dir);
     s = superfile + strlen(superfile) - 1;
     if (*s != '/')
@@ -1423,7 +1423,7 @@ char *cmd;		/* name of command being started */
     (void) sprintf(Logname, "LOGNAME=%s", s);
 
     if (strlen(SAFE_PATH) > sizeof(SafePath)-6) {
-	Error(0, 0, "%t\n\tRidiculously long SAFE_PATH.\n");
+	Error(0, 0, "$$\n\tRidiculously long SAFE_PATH.\n");
 	return NULL;
     }
     /* I've screwed up SAFE_PATH so often (and so have others) that I'm gonna
@@ -1435,7 +1435,7 @@ char *cmd;		/* name of command being started */
 	(void) sprintf(SafePath, "PATH=%s", SAFE_PATH);
 
     if (strlen(cmd) > sizeof(Cmd)-5) {
-	Error(0, 0, "%t\n\tRidiculously long original string.\n");
+	Error(0, 0, "$$\n\tRidiculously long original string.\n");
 	return NULL;
     }
     (void) sprintf(Cmd, "SUPERCMD=%s", cmd);
@@ -1481,7 +1481,7 @@ char *cmd;		/* name of command being started */
 	if (s) {
 	    env[j] = s;
 	    if (strlen(env[j])+1 > localinfo.maxenvlen) {
-		Error(0, 0, "%t\n\tDefinition for envvar %s exceeds \
+		Error(0, 0, "$$\n\tDefinition for envvar %s exceeds \
 maxenvlen=%d.\n", *p, localinfo.maxenvlen);
 		return NULL;
 	    }
@@ -1520,8 +1520,8 @@ maxenvlen=%d.\n", *p, localinfo.maxenvlen);
     }
 
     if (i >= NELEM(env)-1) {
-	Error(0, 0, "%t\n\tAsked to save too many \
-environment variables (max allowed %d).\n", NELEM(env)-1);
+	Error(0, 0, "$$\n\tAsked to save too many \
+environment variables (max allowed %d).\n", (int) NELEM(env)-1);
 	return NULL;
     }
 
@@ -1553,11 +1553,11 @@ char **argv;
 	totlen += l;
 	if (localinfo.maxlen1arg >= 0 && l > localinfo.maxlen1arg)
 	    return Error(0, 0, "Maximum length of each argument = %d chars\n",
-							localinfo.maxlen1arg);
+						    (int) localinfo.maxlen1arg);
     }
     if (localinfo.maxlenargs >= 0 && totlen > localinfo.maxlenargs)
 	return Error(0, 0, "Maximum total length of arguments = %d chars\n",
-							localinfo.maxlenargs);
+						    (int) localinfo.maxlenargs);
     return 0;
 }
 
