@@ -538,7 +538,12 @@ char*	do_variables P__(( char *str));
 char*	docrypt P__((char *key, char *salt));
 char*	ends P__(( char *s1, char *s2 ));
 #ifdef HAVE_STDARG_H
+#ifdef HAVE___ATTRIBUTE__
+int     Error P__(( int show_perror, int die, char * fmt, ... )) __attribute__ ((format (printf, 3, 4)));
+#else
 int	Error P__(( int show_perror, int die, char * fmt, ... ));
+#endif
+
 #else
 int	Error();
 #endif
