@@ -1,4 +1,4 @@
-static const char rcsid[] = "$Id: time.c,v 1.28 2004/04/30 17:00:58 will Exp $";
+static const char rcsid[] = "$Id: time.c,v 1.29 2020/08/03 17:13:04 will Exp $";
 #include "super.h"
 
 #define ANYDAY 7
@@ -83,7 +83,7 @@ int invert;	/* Inverts the test */
     for (iwd=0, match=0; (tok=wdlist[iwd]); iwd++) {
 	new = (TimeList *) malloc(sizeof(TimeList));
 	if (!new)
-	    return Error(0, 0, "%t\n\tFailed to malloc space for time entry\n");
+	    return Error(0, 0, "$$\n\tFailed to malloc space for time entry\n");
 	new->next = tl->next;
 	new->te.invert = invert;
 	/* interpret pat */
@@ -299,8 +299,8 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
 
     if (strlen(str) > MAX_T_FIELDLEN) {
 	return Error(0, 0,
-		"%t\n\tInvalid time range; first %d chars are: <%*.*s>\n",
-		MAX_T_FIELDLEN, MAX_T_FIELDLEN, str);
+		"$$\n\tInvalid time range; first %d chars are: <%*.*s>\n",
+		MAX_T_FIELDLEN, MAX_T_FIELDLEN, MAX_T_FIELDLEN, str);
     }
 
 #ifdef HAVE_LOCALE_H
@@ -321,17 +321,17 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
 	    relop = (*s == '=') ? (s++, GE) : GT;
 	    break;
 	default:
-	    return Error(0, 0, "%t\n\tInvalid time range <%s>\n", str);
+	    return Error(0, 0, "$$\n\tInvalid time range <%s>\n", str);
 	}
 	if (!isdigit(*s))
 	    return Error(0, 0,
-		"%t\n\tInvalid time range <%s> (invalid hour part)\n",
+		"$$\n\tInvalid time range <%s> (invalid hour part)\n",
 	    str);
 
 	hh1 = strtol(s, &p, 10);
 	if (p == s || hh1 > 24 || hh1 < 0)
 	    return Error(0, 0,
-		"%t\n\tInvalid time range <%s> (invalid hour part)\n", str);
+		"$$\n\tInvalid time range <%s> (invalid hour part)\n", str);
 
 	s = p;
 	if (*s != ':') {
@@ -341,7 +341,7 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
 	    mm1 = strtol(++s, &p, 10);
 	    if (p == s || mm1 > 59 || mm1 < 0 || (mm1 > 0 && hh1 == 24))
 		return Error(0, 0,
-		"%t\n\tInvalid time range <%s> (invalid minute part)\n", str);
+		"$$\n\tInvalid time range <%s> (invalid minute part)\n", str);
 	}
 
 	s = p;
@@ -365,7 +365,7 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
 	    break;
 	default:
 	    return Error(0, 0,
-			"%t\n\tInternal time range error -- relop is %d\n",
+			"$$\n\tInternal time range error -- relop is %d\n",
 			relop);
 	}
 
@@ -376,7 +376,7 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
 	hh1 = strtol(s, &p, 10);
 	if (p == s || hh1 > 24 || hh1 < 0)
 	    return Error(0, 0,
-		"%t\n\tInvalid time range <%s> (invalid first hr)\n", str);
+		"$$\n\tInvalid time range <%s> (invalid first hr)\n", str);
 
 	s = p;
 	if (*s != ':') {
@@ -385,7 +385,7 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
 	    mm1 = strtol(++s, &p, 10);
 	    if (p == s || mm1 > 59 || mm1 < 0 || (mm1 > 0 && hh1 == 24))
 		return Error(0, 0,
-		    "%t\n\tInvalid time range <%s> (invalid first min)\n", str);
+		    "$$\n\tInvalid time range <%s> (invalid first min)\n", str);
 	}
 
 	*t1 = hh1*60 + mm1;
@@ -393,13 +393,13 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
 	s = p;
 	if (*s++ != '-')
 	    return Error(0, 0,
-	    "%t\n\tInvalid time range <%s> (expected '-' in hh:mm-hh:mm)\n",
+	    "$$\n\tInvalid time range <%s> (expected '-' in hh:mm-hh:mm)\n",
 	    str);
 
 	hh2 = strtol(s, &p, 10);
 	if (p == s || hh2 > 24 || hh2 < 0)
 	    return Error(0, 0,
-		"%t\n\tInvalid time range <%s> (invalid second hr)\n", str);
+		"$$\n\tInvalid time range <%s> (invalid second hr)\n", str);
 
 	s = p;
 	if (*s != ':') {
@@ -408,14 +408,14 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
 	    mm2 = strtol(++s, &p, 10);
 	    if (p == s || mm2 > 59 || mm2 < 0 || (mm2 > 0 && hh2 == 24))
 		return Error(0, 0,
-		    "%t\n\tInvalid time range <%s> (invalid second min)\n",
+		    "$$\n\tInvalid time range <%s> (invalid second min)\n",
 		    str);
 	}
 
 	s = p;
 	if (*s != '\0' && *s != '/')
 	    return Error(0, 0,
-	    "%t\n\tInvalid time range <%s> (invalid char after time range)\n",
+	    "$$\n\tInvalid time range <%s> (invalid char after time range)\n",
 	    str);
 
 	*t2 = hh2*60 + mm2;
@@ -456,7 +456,7 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
 	}
 	if (i >= 7)
 	    return Error(0, 0,
-		"%t\n\tInvalid time range <%s> (invalid day field)\n",
+		"$$\n\tInvalid time range <%s> (invalid day field)\n",
 		str);
     }
     /* Convert 24:00 to 23:59 */
@@ -465,7 +465,7 @@ char *d;	/* Returned with day number (0=Sunday) or ANYDAY */
     if (*t2 == 24*60)
 	(*t2)--;
     if (*t1 < 0 || *t2 < 0 || *t1 > 24*60-1 || *t2 > 24*60-1)
-	return Error(0, 0, "%t\n\tInvalid time range <%s>\n", str);
+	return Error(0, 0, "$$\n\tInvalid time range <%s>\n", str);
     return 0;
 }
 
@@ -496,19 +496,19 @@ char *d;	/* Returned with day number (0=Sunday) */
 #endif
 
     if (strlen(str) > sizeof(buf)-1)
-	return Error(0, 0, "%t\n\tInvalid time <%s>\n", str);
+	return Error(0, 0, "$$\n\tInvalid time <%s>\n", str);
     if (sscanf(str, "%d:%d/%s", &hh, &mm, buf) != 3) {
 	mm = 0;
 	if ( (sscanf(str, "%d:/%s", &hh, buf) != 2) &&
 		(sscanf(str, "%d/%s", &hh, buf) != 2) ) {
 	    return Error(0, 0,
-	    "%t\n\tInvalid time <%s>; format must be hh[:mm]/dayname\n", str);
+	    "$$\n\tInvalid time <%s>; format must be hh[:mm]/dayname\n", str);
 	}
     }
     if (hh > 23 || hh < 0)
-	return Error(0, 0, "%t\n\tInvalid time <%s> (invalid hr)\n", str);
+	return Error(0, 0, "$$\n\tInvalid time <%s> (invalid hr)\n", str);
     if (mm > 59 || mm < 0)
-	return Error(0, 0, "%t\n\tInvalid time <%s> (invalid min)\n", str);
+	return Error(0, 0, "$$\n\tInvalid time <%s> (invalid min)\n", str);
 
     *t = hh*60 + mm;
 
@@ -526,7 +526,7 @@ char *d;	/* Returned with day number (0=Sunday) */
 	}
     }
     if (i >= 7)
-	return Error(0, 0, "%t\n\tInvalid time <%s> (invalid dayname)\n", str);
+	return Error(0, 0, "$$\n\tInvalid time <%s> (invalid dayname)\n", str);
 
     return 0;
 }
