@@ -1,4 +1,4 @@
-static const char rcsid[] = "$Id: utils.c,v 1.157 2007/03/07 14:48:15 will Exp $";
+static const char rcsid[] = "$Id: utils.c,v 1.159 2020/08/03 17:13:04 will Exp $";
 #include "super.h"
 
 /* Variables table flag -- !0 means has been created */
@@ -248,7 +248,7 @@ int *code;
 #endif
 	} else {
 	    free(new_s);
-	    return Error(0, 0, "%t\n\tUnknown syslog code <%s>\n", word);
+	    return Error(0, 0, "$$\n\tUnknown syslog code <%s>\n", word);
 	}
     }
     free(new_s);
@@ -366,7 +366,7 @@ char *outbuf;		/* output buffer; NULL means to use the
     } else {
 	if (!(t = outbuf = checksize(&ebuf_clean, ebuf.nalloc))) {
 	    Error(1, 0,
-		"%t\n\tFailed to malloc space for clean copy of input text\n");
+		"$$\n\tFailed to malloc space for clean copy of input text\n");
 	    return NULL;
 	}
     }
@@ -499,12 +499,12 @@ gid_t *req_gid;		/* NULL if default, else ptr to required gid;
     fl = (FileList *) malloc(sizeof(FileList));
     if (!fl) {
 	Error(0, 0,
-	"%tFailed to malloc list member space for include file <%s>\n", name);
+	"$$Failed to malloc list member space for include file <%s>\n", name);
 	return NULL;
     }
 
     if (!(fl->givenname = malloc(strlen(name)+1)) ) {
-	Error(0, 0, "%tFailed to malloc space for filename <%s>\n", name);
+	Error(0, 0, "$$Failed to malloc space for filename <%s>\n", name);
 	return NULL;
     }
     strcpy(fl->givenname, name);
@@ -520,7 +520,7 @@ gid_t *req_gid;		/* NULL if default, else ptr to required gid;
 	    l2 = strlen(name);
 	    if (!(fl->fullname = malloc(l1+l2+1)) ) {
 		Error(0, 0,
-		    "%tFailed to malloc space for expanded filename of <%s>\n",
+		    "$$Failed to malloc space for expanded filename of <%s>\n",
 		    name);
 		return NULL;
 	    }
@@ -602,7 +602,7 @@ gid_t *req_gid;		/* NULL if default, else ptr to required gid;
 	 */
 	pass = getpwuid(st.st_uid);
 	if (!pass) {
-	    Error(0, 0, "%t\n\tSuper.tab file `%s' owner uid is %d, \
+	    Error(0, 0, "$$\n\tSuper.tab file `%s' owner uid is %d, \
 which has not passwd entry!\n", fl->fullname, st.st_uid);
 	    return NULL;
 	}
@@ -704,7 +704,7 @@ gid=%d), but is uid=%d, gid=%d\n",
     }
 
     if ((fl->fp = fopen(fl->fullname, "r")) == NULL) {
-	Error(1, 0, "%t\n\tCouldn't open super.tab %sfile `%s': ",
+	Error(1, 0, "$$\n\tCouldn't open super.tab %sfile `%s': ",
 		parent == NULL ? "" : "include ", fl->fullname);
 	return NULL;
     }
@@ -1327,7 +1327,7 @@ char *vardefn;
     if (!created_variables_table) {
 	if (!s_hcreate(HS_VARS, 1000))
 	    return Error(0, 0,
-		"%tCouldn't allocate hash table for variable processing\n");
+		"$$Couldn't allocate hash table for variable processing\n");
 	created_variables_table = 1;
     }
 
@@ -1339,7 +1339,7 @@ char *vardefn;
     dataspace = malloc(lb+1);
     if (!keyspace || !dataspace) {
 	return Error(0, 0,
-	    "%tFailed to allocate space for definition of variable `%s'\n",
+	    "$$Failed to allocate space for definition of variable `%s'\n",
 	    varname);
     }
 
@@ -1359,7 +1359,7 @@ char *vardefn;
     }
     if (!s_hsearch(HS_VARS, item, ENTER))
 	return Error(0, 0,
-	"%tFailed to allocate space for hash-table entry for variable `%s'\n",
+	"$$Failed to allocate space for hash-table entry for variable `%s'\n",
 		varname);
 
     return 0;
@@ -1533,7 +1533,7 @@ char *string;
 
     if (!created_variables_table) {
 	Error(0, 0,
-"%tNo variables have been defined, but super.tab file is using some anyway!\n");
+"$$No variables have been defined, but super.tab file is using some anyway!\n");
 	return NULL;
     }
 
@@ -1541,7 +1541,7 @@ char *string;
 
     /* Initialize the buffer to be at least the same size as the input buffer */
     if (!checksize(&variablebuf, ebuf.l)) {
-	Error(1, 0, "%tCouldn't increase space for variable processing\n");
+	Error(1, 0, "$$Couldn't increase space for variable processing\n");
 	return NULL;
     }
 
@@ -1591,12 +1591,12 @@ char *string;
 	     * character was alphabetic
 	     */
 	    if (tail == dollar+2) {
-		Error(0, 0, "%tEmpty variable name is illegal: `$()'\n");
+		Error(0, 0, "$$Empty variable name is illegal: `$()'\n");
 		return NULL;
 
 	    } else if (*tail != ')' || !isalpha(*(dollar+2))) {
-		Error(0, 0, "%tNot a valid variable name: `%.*s'\n",
-				tail+1-dollar, dollar);
+		Error(0, 0, "$$Not a valid variable name: `%.*s'\n",
+				(int) (tail+1-dollar), dollar);
 		return NULL;
 	    }
 	    savechar = '\0';
@@ -1607,7 +1607,7 @@ char *string;
 	} else {
 	    /* All other $X is error */
 	    Error(0, 0,
-		"%tIllegal variable name `$%c'.  \n\
+		"$$Illegal variable name `$%c'.  \n\
 (Use `$$' to get a plain `$' passed on to the rest of file parsing.)\n", c);
 	    return NULL;
 	}
@@ -1620,13 +1620,13 @@ char *string;
 	    wanted_item.key = varname;
 	    found_item = s_hsearch(HS_VARS, wanted_item, FIND);
 	    if (!found_item) {
-		Error(0, 0, "%t\n\tNo such variable as `$%s'\n",
+		Error(0, 0, "$$\n\tNo such variable as `$%s'\n",
 			wanted_item.key);
 		return NULL;
 	    }
 	    l = strlen(found_item->data);
 	    if (!checksize(&variablebuf, ROUNDUP(l+1, 1024))) {
-	    Error(1, 0, "%tCouldn't increase space for variable processing\n");
+	    Error(1, 0, "$$Couldn't increase space for variable processing\n");
 		return NULL;
 	    }
 	    strcpy(variablebuf.buf+variablebuf.l, found_item->data);
@@ -2089,14 +2089,14 @@ void *
 my_malloc(size_t size)
 {
     void *p = malloc(size);
-    printf("my_malloc(%d) -> %p\n", size, p);
+    printf("my_malloc(%lu) -> %p\n", (long unsigned int) size, p);
     return p;
 }
 void *
 my_realloc(void *ptr, size_t size)
 {
     void *p = realloc(ptr, size);
-    printf("my_realloc(%p, %d) -> %p\n", ptr, size, p);
+    printf("my_realloc(%p, %lu) -> %p\n", ptr, (long unsigned int) size, p);
     return p;
 }
 void
